import { Document, Mongoose, Schema } from 'mongoose';
export interface CounterOptions {
    id: string | null;
    incField: string;
    referenceFields?: string[];
    collectionName: string;
    [k: string]: any;
}
export interface CounterDocument extends Document {
    id: String;
    reference: String[];
    counter: Number;
}
export declare type StringMap = {
    [k: string]: string;
};
declare class MongooseCounter {
    private schema;
    private options;
    private useReference;
    private counterModel;
    private isNew;
    constructor(mongoose: Mongoose, schema: Schema, options?: Partial<CounterOptions>);
    initialize(): void;
    /**
     * Create a model for the counter.
     *
     * @private
     * @param {Mongoose} mongoose
     * @returns
     * @memberof MongooseCounter
     */
    private createCounterModel;
    /**
     * Enrich the schema with keys needed by this counter.
     *
     * @private
     * @memberof MongooseCounter
     */
    private addCounterToSchema;
    /**
     * Set some useful methods on the schema.
     *
     * @private
     * @memberof MongooseCounter
     */
    private addStaticMethods;
    /**
     * Set and handler for hooks on the schema referenced by this sequence.
     *
     * @private
     * @memberof MongooseCounter
     */
    private addHooks;
    /**
     * Given a mongoose document values of the fields set as reference for the counter.
     *
     * @private
     * @param StringMap document A mongoose document values
     * @returns An array of strings which represent the value of the reference
     * @memberof MongooseCounter
     */
    private getReferenceField;
}
/**
 * Initialize
 *
 * @export
 * @param {Mongoose} mongoose Instance to use
 * @returns
 */
export default function mongooseCounter(mongoose: Mongoose): (schema: Schema, options?: Partial<CounterOptions> | undefined) => MongooseCounter;
export {};
